@@ -866,7 +866,7 @@ def save_KL(fractions, background, this_type, offset, args):
     # We will only consider in frame KL
     offset_list = []
 
-    if offset == "final":
+    if offset == "final":  # i.e. this from the final bed file where "end" now refers to end of start codon
         offset = 2  # because need to subtract 2 to get start of codon
 
     for this_offset in fractions.keys():
@@ -1086,6 +1086,25 @@ def write_combined_distinct_bedgraph(df, best_nt_offsets, args):
     df.to_csv(outfile, sep="\t", header=True, index=False, na_rep="NA")
 
 
+def write_rust(full_d, best_nt_offsets, args):
+    """
+    This function writes out the RUST ratios
+    """
+
+    outfile = args.output_directory + args.output + ".rust_values.csv"
+
+    with open(outfile, 'w') as file:
+        file.write("read_type,offset,codon,rust_ratio\n")
+
+    for read_type, this_d in full_d.items():
+        if read_type in best_nt_offsets.keys():
+            for offset, codon_d in this_d.items():
+                codon_offset = int(offset - best_nt_offsets[read_type])
+                with open(outfile, 'a') as file:
+                    for codon, ratio in codon_d.items():
+                        file.write(read_type+','+str(codon_offset)+','+codon+','+str(ratio)+'\n')
+
+
 def write_files(df, full_d, best_nt_offsets, args, r_values, oof_d, frameness_d, fasta_d):
     print("Writing files...")
 
@@ -1094,6 +1113,9 @@ def write_files(df, full_d, best_nt_offsets, args, r_values, oof_d, frameness_d,
     if args.plot_graphs:
         generate_plots(full_d, best_nt_offsets)
 
+    if args.write_rust:
+        write_rust(full_d, best_nt_offsets, args)
+
     if args.keep_read_types_distinct:
         write_combined_distinct_bedgraph(df, best_nt_offsets, args)
 
@@ -1431,8 +1453,8 @@ def main():
     parser.add_argument("-ar", "--min_abundance_ref", required=False, type=float, default=0.1,
                         help="Minimum fraction of total reads that a read type must represent for calculation of "
                              "a reference offset (using start and stop codon enrichment) to be attempted. Default=0.1 "
-                             "(10%). Warning - using low values may promote inclusion of reads which are primarily "
-                             "out of frame. Recommended to keep above 5%. Read fractions are calculated for reads "
+                             "(10pc). Warning - using low values may promote inclusion of reads which are primarily "
+                             "out of frame. Recommended to keep above 0.05. Read fractions are calculated for reads "
                              "within the annotated CDS - UTRs are ignored.")
     parser.add_argument("-ms", "--min_score", required=False, type=float, default=0.7,
                         help="The minimum correlation between the reference and the RUST ratios for the "
@@ -1471,6 +1493,8 @@ def main():
                              "Length is measured in nt. Default = -22")
     parser.add_argument("-ig", "--ignore", required=False, default="None", type=str,
                         help="Read types to ignore. Can add multiple with a colon separator. Eg -ig 27_2:23_1.")
+    parser.add_argument("-wr", "--write_rust", required=False, action="store_true",
+                        help="Write a csv of rust values for each read ")
     parser.add_argument("-of", "--offset", required=False, type=str, default="None",
                         help="If read types are specified with -rt, one can also specify a specific "
                              "offset from the 3' end of the read. "
@@ -1537,13 +1561,13 @@ def main():
     parser.add_argument("--frameness_ratio", type=float, default=1.2, required=False,
                         help="The level of enrichment near the start codon versus downstream for a read type to be "
                              "reported as potentially having strong bias towards out of frame ribosomes. "
-                             "Default = 1.2 i.e. 20%")
+                             "Default = 1.2 i.e. 20percent")
     parser.add_argument("-orf", "--orf_search", action="store_true", default=False,
                         help="Assess whether reads are out of frame by looking for enrichment of each read type "
                              "at positions which have alternative reading frames. The search for ORFs takes "
                              "quite a long time, so this option is disabled by default.")
     parser.add_argument("-mm", "--mismatches", action="store_true", default=False,
-                        help="Whether to consider first nt mismatches. Only available when a bed file is provided")
+                        help="Whether to consider first nt mismatches. Only available when a bam file is provided")
     parser.add_argument("-krd", "--keep_read_types_distinct", action="store_true", default=False,
                         help="Write out a single bedgraph, but keep the read types distinct (useful for downstream"
                              "analysis). Default = False")
@@ -1569,6 +1593,7 @@ def main():
     parser.add_argument("--oof_plot_stride", type=int, default=50,
                         help="How wide each of the windows in the oof heatmap should be in nucleotides. Default=50nt")
 
+
     args = parser.parse_args()
     args = check_args(args)
 
